# Generated by Django 2.1.1 on 2019-03-25 10:34

from django.db import migrations
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('documentos', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='certidao',
            name='cartorio',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Cartório'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='data',
            field=djangoplus.db.models.fields.DateField(blank=True, null=True, verbose_name='Data'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='folha',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Folha'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='livro',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Livro'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='municipio',
            field=djangoplus.db.models.fields.ForeignKey(null=True, blank=True, on_delete=django.db.models.deletion.CASCADE, to='enderecos.Municipio', verbose_name='Município'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='tipo',
            field=djangoplus.db.models.fields.CharField(choices=[['Nascimento', 'Nascimento'], ['Casamento', 'Casamento'], ['Novo Modelo', 'Novo Modelo']], max_length=255, verbose_name='Tipo'),
        ),
    ]
